##  Testing a Calculation
To test a calculation on specific fact sheets without updating the actual data, follow these steps:
  1. On the calculation page, click Test Run.
  2. In the modal that appears, find the fact sheet you want to test, then click Request Run (arrow icon) on the right.


The status and output update based on the test run. You can perform test runs on multiple fact sheets. If test runs are successful, you can activate and run the calculation. If a calculation fails on some fact sheets, check the output and adjust the code accordingly.
![Testing a Calculation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2745fd9c7a4410149679e2d6c0027ac8_LowRes.png)
Testing a Calculation
